<?php

class ControllerApiFurgonetka extends Controller
{
    const INVALID_CREDENTIALS_ERROR = "Invalid credentials";

    public function index()
    {
        $this->load->model('account/api');
        $this->load->model('checkout/order');
        $json = [];
        $limit = 50;
        $datetime = date('Y-m-d H:i:s');

        if (isset($this->request->post['limit'])) {
            $limit = (int)$this->request->post['limit'];
            if ($limit > 50) {
                $limit = 50;
            }
        }
        if (isset($this->request->post['datetime'])) {
            $datetime = $this->request->post['datetime'];
        }

        if (isset($this->request->post['key'])) {
            $api_info = $this->model_account_api->login('Furgonetka', $this->request->post['key']);

            if ($api_info) {
                $ip_data = [];
                $ip = $this->request->server['REMOTE_ADDR'];
                $api_id = $api_info['api_id'];

                $results = $this->model_account_api->getApiIps($api_info['api_id']);

                foreach ($results as $result) {
                    $ip_data[] = trim($result['ip']);
                }

                if (!in_array($ip, $ip_data)) {
                    $this->db->query("INSERT INTO `" . DB_PREFIX . "api_ip` (api_id, ip) VALUES ('$api_id', '$ip')");
                }
                $session = new Session($this->config->get('session_engine'), $this->registry);
                $session->start();
                $this->model_account_api->addApiSession(
                    $api_info['api_id'],
                    $session->getId(),
                    $this->request->server['REMOTE_ADDR']
                );
                $session->data['api_id'] = $api_info['api_id'];

                $json['orders'] = [];

                $orders = $this->db->query(
                    "SELECT order_id FROM `" . DB_PREFIX . "order` WHERE date_modified>'$datetime' order by date_modified limit $limit"
                );

                foreach ($orders->rows as $order) {
                    $orderData = $this->model_checkout_order->getOrder($order['order_id']);

                    $orderProducts = $this->model_checkout_order->getOrderProducts($order['order_id']);
                    $orderProductsArray = [];
                    $priceTotal = 0.0;
                    $codAmount = 0.0;

                    foreach ($orderProducts as $orderProduct) {
                        $orderProductsArray[] = [
                            'sourceProductId' => $orderProduct['product_id'],
                            'name' => $orderProduct['name'] . ' ' . $orderProduct['model'],
                            'priceGross' => $orderProduct['price'],
                            'quantity' => $orderProduct['quantity'],
                        ];

                        $priceTotal += $orderProduct['price'] * $orderProduct['quantity'];
                    }

                    if ($orderData['payment_code'] == 'cod') {
                        $codAmount = $priceTotal;
                    }

                    $json['orders'][] = [
                        'sourceOrderId' => $orderData['order_id'],
                        'sourceClientId' => $orderData['customer_id'],
                        'datetimeOrder' => $orderData['date_added'],
                        'sourceDatetimeChange' => $orderData['date_modified'],
                        'status' => $orderData['order_status'],
                        'totalPrice' => $priceTotal,
                        'codAmount' => $codAmount,
                        'comment' => $orderData['custom_field'],
                        'paymentMethod' => $orderData['payment_method'],
                        'shippingAddress' => [
                            'company' => $orderData['shipping_company'],
                            'name' => $orderData['shipping_firstname'],
                            'surname' => $orderData['shipping_lastname'],
                            'street' => $orderData['shipping_address_1'] . ' ' . $orderData['shipping_address_1'],
                            'city' => $orderData['shipping_city'],
                            'postcode' => $orderData['shipping_postcode'],
                            'countryCode' => $orderData['shipping_iso_code_2'],
                            'phone' => $orderData['telephone'],
                            'email' => $orderData['email'],
                        ],
                        'products' => $orderProductsArray,
                    ];
                }
            } else {
                $json['error'] = self::INVALID_CREDENTIALS_ERROR;
            }
        } else {
            $json['error'] = self::INVALID_CREDENTIALS_ERROR;
        }

        $this->response->addHeader('Content-Type: application/json');
        $this->response->setOutput(json_encode($json));
    }
}
